#
# spec file for package qpdf
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qpdf
Version:        5.1.3
Release:        5.1
%define so_version 13
Summary:        Command-line tools and library for transforming PDF files
License:        Artistic-2.0
Group:          Development/Libraries/C and C++
Url:            http://qpdf.sourceforge.net/
Source:         http://sourceforge.net/projects/qpdf/files/qpdf/%{version}/qpdf-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
QPDF is a program that does structural, content-preserving
transformations on PDF files.  It could have been called something
like pdf-to-pdf.  It also provides many useful capabilities to
developers of PDF-producing software or for people who just want to
look at the innards of a PDF file to learn more about how they work.

QPDF offers many capabilities such as linearization (web
optimization), encrypt, and decryption of PDF files.  Note that QPDF
does not have the capability to create PDF files from scratch; it is
only used to create PDF files with special characteristics starting
from other PDF files or to inspect or extract information from
existing PDF files.

%package devel

Summary:        Development files for qpdf PDF manipulation library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libstdc++-devel

%description devel
The qpdf-devel package contains header files and libraries necessary
for developing programs using the qpdf library.

%package -n libqpdf%{so_version}
Summary:        Shared libraries for qpdf
Group:          Development/Libraries/C and C++

%description -n libqpdf%{so_version}
This packages contains the shared libraries required for the qpdf
package.

%prep
%setup -q

%build
export CXXFLAGS="%optflags -fvisibility-inlines-hidden"
%configure --disable-static --disable-test-compare-images \
           --docdir='${datarootdir}'/doc/packages/%{name} \
           --enable-show-failed-test-output
make %{?_smp_mflags}

%check
make check
rm -rf qpdf/qtest # Unicode data can't be redistributed freely

%install
%makeinstall

rm %{buildroot}%{_libdir}/*.la

%post -n libqpdf%{so_version} -p /sbin/ldconfig

%postun -n libqpdf%{so_version} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%dir %{_datadir}/doc/packages/%{name}
%doc %{_datadir}/doc/packages/%{name}/*
%doc ChangeLog Artistic-2.0
%{_bindir}/*
%{_mandir}/man1/*

%files -n libqpdf%{so_version}
%defattr(-,root,root)
%{_libdir}/libqpdf.so.%{so_version}*

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/pkgconfig/libqpdf.pc
%{_libdir}/libqpdf.so

%changelog
* Mon May 25 2015 idonmez@suse.com
- Update to version 5.1.3
  * Handle object streams with more than 255 objects
  * Security fixes courtesy of Google Security Team
  * Properly handle pages that have no content
  * Robustness fixes for invalid PDF files
* Thu Jun 12 2014 idonmez@suse.com
- Update to version 5.1.2
  * Please see the included ChangeLog file
* Wed Jan 29 2014 jsmeix@suse.de
- Provide the license source file Artistic-2.0 in the binary RPM
  (fix declined IBS submitrequest 30947).
* Fri Jan 17 2014 idonmez@suse.com
- Update to version 5.1.1
  * Fixes https://github.com/qpdf/qpdf/issues/28
* Wed Dec 18 2013 idonmez@suse.com
- Update to version 5.1.0
  * Add ability to provide your own source of random numbers
    at runtime
  * More handling of damaged PDF files
* Tue Oct 22 2013 idonmez@suse.com
- Update to version 5.0.1
  * Some security fixes, courtesy of Redhat
* Wed Jul 10 2013 idonmez@suse.com
- Update to 5.0.0
  * Same as 4.2.0 but shared lib version bumped due to ABI changes
- Apply shared library packaging policy
* Mon Jul  8 2013 idonmez@suse.com
- Update to version 4.2.0
  * Fixes bug that would result in the loss of compressible objects
    whose generation numbers were greater than 0 when generating
    object streams.
  * Added better API calls for handling object ID and generation
    together as a QPDFObjGen.
  * Added --show-npages option to the qpdf command-line tool.
  * Several small enhancements to make qpdf able to handle a wider
    range of broken input files.
* Sun Apr 14 2013 idonmez@suse.com
- Update to version 4.1.0
  * New API calls for parsing PDF content streams
  * qpdf --check now parses all pages' content streams in addition
    to doing other checks.
  * Overridden compressed objects are properly handled.
- Drop qpdf-ppc64.patch: merged upstream
* Thu Jan  3 2013 dvaleev@suse.com
- Detect binary attachments better (qpdf-ppc64.patch)
  This fix eliminates a false test failure on some platforms and makes
  the binary test work properly whether characters with the high bit
  set, when treated as integers, are negative or not.
- pass --enable-show-failed-test-output to configure, to see
  detailed failure reason in build log.
* Mon Dec 31 2012 idonmez@suse.com
- Update to version 4.0.0
  * Support for Acrobat X & XI encryption
  * Support for extension levels in PDF version information.
  * New methods for supporting read and write from/to arbitrary sources.
  * Support for unencrypted files with encrypted attachments.
  * Support for files with junk preceding the PDF header.
* Fri Sep  7 2012 idonmez@suse.com
- Update to version 3.0.2
  * Calling QPDFWriter::setOutputMemory would result in a
  segmentation fault from write() if setStaticID() was not used.
  * New method call QPDFWriter::setExtraHeaderText to add text
  * Make it so that you can write the same QPDF object through two
  different QPDFWriter objects that both have linearization enabled.
* Sat Aug 11 2012 idonmez@suse.com
- Update to version 3.0.1
  * qpdf may falsely report premature EOF when reading files that
    have object streams that end with scalars not followed by
    whitespace.
* Thu Aug  2 2012 idonmez@suse.com
- Update to version 3.0.0
  * Page-based splitting and merging
  * Support for large files
  * The ability to set the encryption parameters of one file by copying
    them from another file.
  * Support for creating PDF files from scratch
- Drop applied patches
* Sun Apr 22 2012 dimstar@opensuse.org
- Add qpdf-gcc47.patch: Fix build with gcc 4.7.
* Mon Feb 27 2012 dmueller@suse.de
- fix build with pcre 8.30
* Tue Jan 24 2012 jengelh@medozas.de
- Remove redundant sections (see specfile guidelines)
* Mon Jan 23 2012 crrodriguez@opensuse.org
- Fix devel package requires
- Build with -fvisibility-inlines-hidden, test suite
  confirms it works and saves a few dozens of entries in the
  exported symbol table.
* Mon Jan  2 2012 idonmez@suse.com
- Update to v2.3.1
  * Fix threading problem with PCRE usage
* Thu Aug  4 2011 idonmez@novell.com
- Update to v2.2.4
  * Build system fixes
- Drop qpdf-gcc46.patch and qpdf-nostrip.patch: applied upstream
* Wed Aug  3 2011 idonmez@novell.com
- Remove unicode data to make sure its not redistributed
* Thu Jun 23 2011 idonmez@novell.com
- Add qpdf-nostrip.patch: don't strip libraries
* Wed Jun 22 2011 idonmez@novell.com
- Update to v2.3.3
  * API improvements
  * Compatibility fixes with some PDF files
* Mon Apr 28 2008 Jay Berkenbilt <ejb@ql.org> - 2.0-1
- Initial packaging
